﻿using IRaCIS.Application.Interfaces;
using IRaCIS.Core.Infra.EFCore;
using IRaCIS.Core.Domain.Share;
using IRaCIS.Core.Application.Filter;
using Microsoft.AspNetCore.Mvc;
using IRaCIS.Core.Application.Service.WorkLoad.DTO;
using Microsoft.AspNetCore.Authorization;
using IRaCIS.Core.Application.Auth;
using IRaCIS.Core.Application.Service.Reading.Dto;
using IRaCIS.Core.Domain.Share.Reading;

namespace IRaCIS.Application.Services
{
    [ApiExplorerSettings(GroupName = "Reading")]
    public class ReadingPeriodSetService : BaseService
    {

        public IRepository<SubjectVisit> _subjectVisitRepository;
        private readonly IRepository<ReadingPeriodSet> _readingPeriodSetRepository;

        public ReadingPeriodSetService(IRepository<SubjectVisit> subjectVisitRepository,
            IRepository<ReadingPeriodSet> ReadingPeriodSetRepository
          )
        {
            _subjectVisitRepository = subjectVisitRepository;
            _readingPeriodSetRepository = ReadingPeriodSetRepository;
        }


        /// <summary>
        /// 新增或者修改
        /// </summary>
        /// <param name="addOrEditReadingPeriodSet"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<IResponseOutput> AddOrUpdateReadingPeriodSet(ReadingPeriodSetAddOrEdit addOrEditReadingPeriodSet)
        {
            var entity = await _repository.InsertOrUpdateAsync<ReadingPeriodSet, ReadingPeriodSetAddOrEdit>(addOrEditReadingPeriodSet, true);
            return ResponseOutput.Ok(entity.Id.ToString());
        }

        /// <summary>
        /// 分页获取
        /// </summary>
        /// <param name="query"></param>
        /// <returns></returns>
        [HttpPost]
        public async Task<PageOutput<ReadingPeriodSetView>>  GetReadingPeriodSetList(ReadingPeriodSetQuery query)
		{
			
		     var readquery =_readingPeriodSetRepository.AsQueryable()
                .WhereIf(query.TrialId!=null,x=>x.TrialId==query.TrialId)
                .WhereIf(query.ReadingPeriodName != null, x => x.ReadingPeriodName.Contains(query.ReadingPeriodName))
                .ProjectTo<ReadingPeriodSetView>(_mapper.ConfigurationProvider);
                var pageList= await readquery.ToPagedListAsync(query.PageIndex, query.PageSize, query.SortField == null ? "CreateTime" : query.SortField,
               query.SortAsc);

            return pageList;
		}



    /// <summary>
    /// 删除
    /// </summary>
    /// <param name="readingPeriodSetId"></param>
    /// <returns></returns>
       [HttpDelete("{readingPeriodSetId:guid}")]
        public async Task<IResponseOutput> DeleteReadingPeriodSet(Guid readingPeriodSetId)
        {
            var success = await _repository.BatchDeleteAsync<ReadingPeriodSet>(t => t.Id == readingPeriodSetId);
            return ResponseOutput.Result(success);
        }
    }
}
